globals
[
  row      ;; this is the current row 
  done?    ;; a flag set to allow you to press the go button multiple times
]

patches-own
[
  value    ;; this variable is a floating point number representing the energy available on a particular patch
]

turtles-own
[
 prod ;; this describes whether (1) or not (0) an agent puts energy into the environment
 consume ;;this describes whether (1) or not (0) and agent consumes energy from the environment
 energy ;;this is the energy store of an agent
 move_amount ;;not subject to ind. var.; this is how much an agent moves in a time step, 0 or 1 in this simulation
 social_move ;;specifies whether the default behavior when another agent is in the patch ahead is to turn around (1) or stay (0)
 bene_appr ;;specifies whether the agent uses a benefit approach rule (1) or does not (0)
 move_propensity;; likelihood of moving in a given time period
 offspring ;; reference to offspring
 parent ;;reference to agent that divided to create this agent
 repro_stat ;;0 for offspring, 1 for ready to reproduce, 2 for investing parent, 3 for post-investment parent
 kin_near ;;cumulative number time periods near kin (parent/offspring)
 nonkin_near ;;cumulative number time periods near another (non parent/offspring)
 none_near ;;number time periods near nobody
 many_near ;;number of time periods two or more other agents are on the same patch
 repro_age
 age
 
] 

to setup
 clear-all
 setup-sim
end

;; initializes the world
to setup-general
  clear-patches
  clear-drawing
  set row max-pycor   ;; set the current row to the top
  set done? false
  ;random-seed random_seed
end

;; set up the simulation and create agents
to setup-sim
  setup-general
  reset-ticks
  ;; introduces agents to initial row
  repeat initial_parents [setup-parent]
  setup-offspring
  ask patches with [pycor = row]
  [
  set value initial_p_val
  color-patch
  ]
end

to setup-parent
 let parent_distance ((min-pxcor - max-pxcor)/ initial_parents)
 crt 1
  [
  set repro_stat 1
  setxy ((who * parent_distance) + 1) row 
  ifelse random 100 < prop_right [set heading 90] [set heading 270]
  set move_propensity parent_move_propensity
  set bene_appr 0
  set prod 1
  set consume 0
  set age 0
  pd
  ]
end 

to setup-offspring
 ask turtles with [repro_stat = 1]
   [
   let cur_parent self
    hatch 1 
     [
     set repro_stat 0
     set energy 0
     set bene_appr 1
     set move_propensity 0
     set heading 90
     fd 1
     set prod 0
     set consume 1
     pd
     ask cur_parent [set offspring myself]
     set parent myself
     ]
    set repro_age age 
    set repro_stat 2 
   ]
end 

;; main routine
to go
  let row-patches patches with [pycor = row]    
  if (row = min-pycor)  ;; if the end has been reached, continue from the top or stop
   [
   set done? true
   ifelse auto-continue?
    [
    setup-continue 
    set row-patches patches with [pycor = row]
    ]
    [
    stop
    ]
   ]   
  environment-go    ;; advance environment down and in time
  population-go
  agent-go          ;; advances agents down and in time
  set row row - 1
  tick
end

;;main loop for environment
to environment-go    
  ask patches with [pycor = row]  
  [
    calculate-next-value                        ;energy of patch at t + 1 is calculated
    if env-instability? [check-clear-energy]
    color-patch
  ]
end

;;main loop for population changes
to population-go

end

;;main loop for turtle behavior
to agent-go
  ask-concurrent turtles    
  [
  time-forward   ;agents go to the next time period
  status-change  ;change in age, reproductive status of agents
  produce        ;agent has the opportunity to produce energy in local environment (and it does not diffuse until the next time period)
  move           ;agent moves according to movement rules 
  process-food
  ]
end

to status-change
 set age (age + 1)
 if repro_stat = 2
  [
  if age - repro_age > PI_time [set repro_stat 3]    ; if PI_time has passed, go to non-investing state
  ]
end

to produce
 ifelse repro_stat = 2 
  [
  set prod 1
  pu
  set xcor xcor + 1                          ;parents drop energy on patch to the right
  set value value + (prod * PI_amount)
  set energy energy - (prod * PI_amount)    ;parents have negative energy corresponding to the amount of PI produced
  if any? turtles-here with [self = [offspring] of myself] [set kin_near kin_near + 1]  
  if any? turtles-here with [(self != myself) and (self != [offspring] of myself)] [set nonkin_near nonkin_near + 1]  
  if count turtles-here = 1  [set none_near none_near + 1]  
  if count turtles-here > 2 [set many_near many_near + 1]
  set xcor xcor - 1
  pd
 ]
 [set prod 0]
end
 
to move
 if random 100 < move_propensity 
  [
  if random 100 < switch_dir [set heading heading + 180]       
  walk-forward
  ]
 if bene_appr = 1 [walk-towards]        ;if approach beneft, follow positive gradient
 ;check-patch-occupied   
 ;if low-move-random? [thresh-move-random]          ;if low-move-random and environment energy is below threshold, agents set heading L or R randomly 
end

;if social_propensity 0, agents never occupy the same patch
to walk-forward  
 ifelse (any? turtles-on patch-ahead 1)   
   [if random 100 < social_propensity [ fd 1]]     ;if there is someone ahead, only moves forward if social propensity high 
   [fd 1]     
end                                   
 
to check-patch-occupied 
 if any? turtles-here 
   [if random 100 < social_propensity [fd 1] ]      ;social propensity for leaving off for now
end
 
;if the patch ahead has more value than the current one, move, else chage heading
to walk-towards
 ifelse [value] of patch-ahead 1 > value
    [walk-forward]
    [set heading heading + 180] 
end 


;;this command is not currently being used but can be used for modeling certain kinds of movement or dispersal
to find-empty-patch
 fd 1
 if count turtles-here > 1 [find-empty-patch]
end


to process-food
 if value > (consume * consume_amount)
  [
  set value value - (consume * consume_amount)
  set energy energy + (consume * consume_amount)
  ]
end

to check-die
  if value <= 0 
   [
   if energy <= 0 
    [die]
   ]
end

;; calculates and sets the value of the patch immediately below self.
to calculate-next-value  ;; patch procedure
  let patch-below (patch-at 0 -1)
  let value-sum ([value] of (patch-at -1 0) + [value] of (patch-at 1 0))  ;diffuse values
  let new-value
        ((1 - diffusion) * value + ((diffusion / 2) * value-sum))
  ask patch-below     ;set new values
   [
   set value new-value
   if value < 0 [ set value 0 ]
   ]
end

to disperse
 ask turtles 
  [
  set xcor (xcor + random-normal 0 disperse_sd)
  if count turtles-here > 1 [find-empty-patch]      ;if agents land on an occupied patch, they die
  ]
end

to color-patch  ;; patch procedure
  set pcolor scale-color pink value -1 3;1.5 -1.5
end

to check-clear-energy
 if random-float 100 < env_instability [set value 0]
end

;;advances time
to time-forward
 set ycor ycor - 1 
 draw-plot
end

to draw-plot
 set-current-plot-pen "blue"
 plot mean [kin_near] of turtles
 set-current-plot-pen "red"
 plot mean [nonkin_near] of turtles
 set-current-plot-pen "black"
 plot mean [none_near] of turtles
 set-current-plot-pen "WA"
 ;plot count turtles with [walk_away = 1]
 set-current-plot-pen "BA"
 ;plot count turtles with [bene_appr = 1]
end

;; copy the bottom row to the top row 
to setup-continue
  let value-list []
  if not done?  ;; make sure go has already been called
    [ stop ]

  ;; copy values from bottom row of patches to top row
  set value-list map [[value] of ?] sort patches with [pycor = row]
  setup-general
  foreach sort patches with [pycor = row]
  [
    ask ?
    [
      set value item (pxcor + max-pxcor) value-list
      color-patch
    ]
  ]
  set done? false
  ask turtles [set ycor max-pycor]
end


@#$#@#$#@
GRAPHICS-WINDOW
485
11
897
12044
100
3000
2.0
1
10
1
1
1
0
1
1
1
-100
100
-3000
3000
1
1
1
ticks

CC-WINDOW
5
12058
906
12153
Command Center
0

SWITCH
261
571
436
604
auto-continue?
auto-continue?
0
1
-1000

SLIDER
327
494
472
527
diffusion
diffusion
0
1
0.5
0.1
1
NIL
HORIZONTAL

BUTTON
115
32
201
65
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL

BUTTON
14
33
99
66
setup
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

SLIDER
16
571
188
604
prop_right
prop_right
0
100
50
50
1
NIL
HORIZONTAL

PLOT
268
25
468
175
Prop Agents
NIL
NIL
0.0
10.0
0.0
200.0
true
false
PENS
"default" 1.0 0 -16777216 true
"Blue" 1.0 0 -13345367 true
"Red" 1.0 0 -2674135 true
"WA" 1.0 0 -955883 true
"BA" 1.0 0 -10899396 true
"black" 1.0 0 -16777216 true

SLIDER
302
814
474
847
env_instability
env_instability
0
1
0.3
.1
1
NIL
HORIZONTAL

TEXTBOX
296
785
468
812
% likelihood that environmental energy will be cleared from patch
11
0.0
1

SWITCH
58
683
197
716
env-instability?
env-instability?
1
1
-1000

SLIDER
21
624
193
657
initial_p_val
initial_p_val
0
2
0
.05
1
NIL
HORIZONTAL

TEXTBOX
179
469
329
487
Advanced settings
14
0.0
1

TEXTBOX
40
136
190
154
Agent movement controls
11
0.0
1

TEXTBOX
40
281
190
299
Investment/consumption
11
0.0
1

SLIDER
19
491
191
524
disperse_sd
disperse_sd
0
50
1
1
1
NIL
HORIZONTAL

BUTTON
216
497
294
530
NIL
disperse
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

MONITOR
206
39
263
84
P
(count turtles with [prod > .75]) / (count turtles)
17
1
11

MONITOR
208
99
265
144
S
(count turtles with [prod < .25]) / (count turtles)
17
1
11

SLIDER
288
256
460
289
initial_parents
initial_parents
0
100
10
1
1
NIL
HORIZONTAL

SLIDER
4
155
212
188
parent_move_propensity
parent_move_propensity
0
100
50
1
1
NIL
HORIZONTAL

SLIDER
23
196
195
229
social_propensity
social_propensity
0
10
1
.01
1
NIL
HORIZONTAL

SLIDER
11
305
183
338
PI_time
PI_time
0
5000
5000
1
1
NIL
HORIZONTAL

SLIDER
19
235
191
268
switch_dir
switch_dir
0
100
5
1
1
NIL
HORIZONTAL

SLIDER
15
345
187
378
PI_amount
PI_amount
0
1
0.05
.05
1
NIL
HORIZONTAL

SLIDER
15
386
187
419
consume_amount
consume_amount
0
1
0.05
.05
1
NIL
HORIZONTAL

@#$#@#$#@
MODEL DESCRIPTION 
-----------

The description follows the standardized ODD (Overview, Design concepts, Details) protocol for describing individual and agent based models (Grimm et al. 2006; Grimm and Railsback 2005). The ODD protocol was designed with extensive input from 20 agent based modelers from a variety of disciplines in order to provide a clear and complete description of agent based models.  Because agent based models have many components and lack the operational simplicity of mathematical models, they can be difficult to describe comprehensibly and completely in a standard methods section. The introduction of the ODD protocol provides an  standard presentation that is logical, well-organized and complete. This protocol is in wide use in diverse fields, from ecology to land-use modeling.
This model was built using NetLogo 4.0.2 (Wilensky 1999) an agent based modeling platform designed for simulating natural and social phenomena. 

Figures and Tables can be found in the corresponding paper (Aktipis and Fernandez-Duque).

Purpose
-----------

This model was developed to explore the parameters under which simple rules promoting parent-offspring proximity can lead to correctly directed parental investment (PI). Parents simply emit benefits and offspring follow positive benefit gradients, leading to proximity maintenance under some conditions. The model explores the effects of mobility, sociality, density and length of PI. We can then speculate that strategies based on recognition and bonding/attachment might serve to increase rates of correctly directed PI under parameters that are shown here to otherwise lead to high rates of misdirected and wasted PI.

State variables and scales
-----------

Time and space are both represented discretely. Space is represented as discrete locations in a one-dimensional line made of 201 lattice locations or patches. Movement of parent agents along this line is determined by their movement propensity, offspring movement is determined by their benefit approach rule. During each time step, agents and patches execute the commands described in the schedule.
As time advances, the system moves down, as in a standard cellular automaton model (Figure 1). This enables visualization of the behavior of the system over time.

(Figure 1 about here)

There are four kinds of entities: global variables which are associated with the overall state of the system (e.g., the number of agents), patches (unique lattice locations) and two types of agents (parents and offspring). Table 1 provides a full description of the state variables associated with each of the entities.

(Table 1 about here)

Process overview and scheduling
-----------

The model proceeds in discrete time steps, and entities execute procedures in the following order (a more detailed schedule is provided in Appendix A):

1.	Resources diffuse between neighboring patches.
2.	Parents produce energy, adding to the resources on the current patch.
3.	Agents move
a.	Parents move according to mobility, and change heading according to turn propensity.
b.	Offspring follow benefit approach rule.
4.	Offspring consume resources from the current patch.

DESIGN CONCEPTS
-----------

Emergence: Parent-offspring proximity emerges from the simple individual-level rules being used by the agents. When this proximity is achieved, it results in correctly directed PI, also an emergent phenomenon.

Adaptation: No evolutionary adaptation occurs.  

Fitness: Although fitness is not explicitly modeled, the level of correct PI may correlate with fitness in certain ecological and social circumstances in which the model may be applied.

Prediction: Agents lack the ability to predict outcomes of future interactions or integrate information across time steps.

Sensing: Offspring have the ability to sense the resource level on the current patch and the patch immediately ahead.

Interaction: Parents and offspring interact indirectly through the shared environment (i.e., the passing of benefits from parents to offspring through patches).  

Stochasticity: Parental mobility, turn propensity, and sociality are modelled probabilistically.

Collectives: Parent-offspring pairs can be considered collectives, but they do not have aggregate variables associated with them.

Observation:  In the first three experiments, 100 independent runs (of length 2000 time steps) took place for each parameter value being explored (Table 2). The amount of correctly directed, misdirected and wasted PI is reported at the end of each run and averaged across all 100 runs. The fourth experiment reports correctly directed, misdirected and wasted PI every time step for 2000 time steps, averaged across 30 runs.

(Table 2 about here)

INITIALIZATION
-----------

All runs were initialized according to default parameters as shown in Table 2. 


Input
-----------

The model has been designed as a general model of PI that may apply across a variety of species. Parents emitted benefits locally and offspring consumed benefits locally, so spatial proximity of parents-offspring pairs resulted in PI. This is consistent with the observations that spatial proximity can enable the selective transmission of benefits to offspring including food, warmth and various kinds of sensory stimulation (Gubernick and Klopfer 1981). It could also be generalized to include the benefits associated with protection from predators (Bowlby 1969; Mason and Mendoza 1998). These observations about PI in various species provided a basis for the assumptions of this model.

APPENDIX A: SUBMODELS
-----------

This section provides additional detail regarding simulation schedule and the subprocesses.

1.	Resources diffuse between neighboring patches: half of the diffusion amount to patch immediately to right, and other half to patch immediately to left
2.	Parents produce energy, adding to the resources on the current patch
3.	Agents move
a.	Parents move according to mobility, change heading with turn propensity
b.	Offspring follow benefit approach rule

If (R < R1), then FD1 else TRN

Where R = resource level on the present patch, R1 = the resource level on the patch ahead, FD1 is the movement command, forward 1, and TRN is the movement command turn around (allowing the organism to repeat this rule facing a different direction in the next time step). 

4.	Offspring consume resources from the current patch




@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 4.0.2
@#$#@#$#@
set roughness 0.002
setup-random
repeat world-height - 1 [ go ]
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="Experiment 1" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2000"/>
    <metric>mean [kin_near] of turtles</metric>
    <metric>mean [nonkin_near] of turtles</metric>
    <metric>mean [none_near] of turtles</metric>
    <enumeratedValueSet variable="social_propensity">
      <value value="0"/>
      <value value="0.5"/>
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="parent_move_propensity">
      <value value="1"/>
      <value value="10"/>
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial_parents">
      <value value="10"/>
      <value value="25"/>
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prop_right">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="random_seed">
      <value value="6433121"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="disperse_sd">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="auto-continue?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consume_amount">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial_p_val">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PI_time">
      <value value="5000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PI_amount">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="env-instability?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="env_instability">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="diffusion">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="switch_dir">
      <value value="5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment 2" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2000"/>
    <metric>mean [kin_near] of turtles</metric>
    <metric>mean [nonkin_near] of turtles</metric>
    <metric>mean [none_near] of turtles</metric>
    <enumeratedValueSet variable="social_propensity">
      <value value="0"/>
      <value value="0.5"/>
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="parent_move_propensity">
      <value value="1"/>
      <value value="10"/>
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial_parents">
      <value value="10"/>
      <value value="25"/>
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prop_right">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="disperse_sd">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="auto-continue?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consume_amount">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial_p_val">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PI_time">
      <value value="5000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PI_amount">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="env-instability?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="env_instability">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="diffusion">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="switch_dir">
      <value value="5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment 3 Density" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2000"/>
    <metric>mean [kin_near] of turtles</metric>
    <metric>mean [nonkin_near] of turtles</metric>
    <metric>mean [none_near] of turtles</metric>
    <enumeratedValueSet variable="social_propensity">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="parent_move_propensity">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial_parents">
      <value value="5"/>
      <value value="10"/>
      <value value="25"/>
      <value value="50"/>
      <value value="75"/>
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prop_right">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="disperse_sd">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="auto-continue?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consume_amount">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial_p_val">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PI_time">
      <value value="5000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PI_amount">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="env-instability?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="env_instability">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="diffusion">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="switch_dir">
      <value value="5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment 4 Mobility" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2000"/>
    <metric>mean [kin_near] of turtles</metric>
    <metric>mean [nonkin_near] of turtles</metric>
    <metric>mean [none_near] of turtles</metric>
    <enumeratedValueSet variable="social_propensity">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="parent_move_propensity">
      <value value="0.1"/>
      <value value="0.5"/>
      <value value="1"/>
      <value value="5"/>
      <value value="10"/>
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial_parents">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prop_right">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="disperse_sd">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="auto-continue?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consume_amount">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial_p_val">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PI_time">
      <value value="5000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PI_amount">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="env-instability?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="env_instability">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="diffusion">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="switch_dir">
      <value value="5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment 5 Mobility B" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2000"/>
    <metric>mean [kin_near] of turtles</metric>
    <metric>mean [nonkin_near] of turtles</metric>
    <metric>mean [none_near] of turtles</metric>
    <enumeratedValueSet variable="social_propensity">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="parent_move_propensity">
      <value value="0"/>
      <value value="5"/>
      <value value="10"/>
      <value value="25"/>
      <value value="50"/>
      <value value="75"/>
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial_parents">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prop_right">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="disperse_sd">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="auto-continue?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consume_amount">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial_p_val">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PI_time">
      <value value="5000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PI_amount">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="env-instability?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="env_instability">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="diffusion">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="switch_dir">
      <value value="5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment 6 PI Length" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2000"/>
    <metric>mean [kin_near] of turtles</metric>
    <metric>mean [nonkin_near] of turtles</metric>
    <metric>mean [none_near] of turtles</metric>
    <enumeratedValueSet variable="social_propensity">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="parent_move_propensity">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial_parents">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prop_right">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="disperse_sd">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="auto-continue?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consume_amount">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial_p_val">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PI_time">
      <value value="5000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PI_amount">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="env-instability?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="env_instability">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="diffusion">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="switch_dir">
      <value value="5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment 7B PI Length-Low Mov" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2000"/>
    <metric>mean [kin_near] of turtles</metric>
    <metric>mean [nonkin_near] of turtles</metric>
    <metric>mean [none_near] of turtles</metric>
    <enumeratedValueSet variable="social_propensity">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="parent_move_propensity">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial_parents">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prop_right">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="disperse_sd">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="auto-continue?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consume_amount">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial_p_val">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PI_time">
      <value value="5000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PI_amount">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="env-instability?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="env_instability">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="diffusion">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="switch_dir">
      <value value="5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment 8B PI Length-High Mov" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2000"/>
    <metric>mean [kin_near] of turtles</metric>
    <metric>mean [nonkin_near] of turtles</metric>
    <metric>mean [none_near] of turtles</metric>
    <enumeratedValueSet variable="social_propensity">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="parent_move_propensity">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial_parents">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prop_right">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="disperse_sd">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="auto-continue?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consume_amount">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial_p_val">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PI_time">
      <value value="5000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PI_amount">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="env-instability?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="env_instability">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="diffusion">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="switch_dir">
      <value value="5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment 9 Sociality" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2000"/>
    <metric>mean [kin_near] of turtles</metric>
    <metric>mean [nonkin_near] of turtles</metric>
    <metric>mean [none_near] of turtles</metric>
    <enumeratedValueSet variable="social_propensity">
      <value value="0"/>
      <value value="0.01"/>
      <value value="0.1"/>
      <value value="1"/>
      <value value="10"/>
      <value value="50"/>
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="parent_move_propensity">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial_parents">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prop_right">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="disperse_sd">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="auto-continue?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consume_amount">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial_p_val">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PI_time">
      <value value="5000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PI_amount">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="env-instability?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="env_instability">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="diffusion">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="switch_dir">
      <value value="5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment 9B Sociality" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2000"/>
    <metric>mean [kin_near] of turtles</metric>
    <metric>mean [nonkin_near] of turtles</metric>
    <metric>mean [none_near] of turtles</metric>
    <enumeratedValueSet variable="social_propensity">
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="parent_move_propensity">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial_parents">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prop_right">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="disperse_sd">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="auto-continue?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consume_amount">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial_p_val">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PI_time">
      <value value="5000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PI_amount">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="env-instability?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="env_instability">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="diffusion">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="switch_dir">
      <value value="5"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
